@@ -103,6 +103,14 @@
         <source>Polish</source>
         <translation>Polonais</translation>
     </message>
+    <message>
+        <source>Catalan</source>
+        <translation>Catalan</translation>
+    </message>
+    <message>
+        <source>Greek</source>
+        <translation>Grec</translation>
+    </message>
 </context>
 <context>
     <name>Bing::DialogWidget</name>
@@ -763,6 +771,14 @@
         <source>Add Ipernity item</source>
         <translation>Ajouter une recherche Ipernity</translation>
     </message>
+    <message>
+        <source>Ipernity item</source>
+        <translation>Recherche Ipernity</translation>
+    </message>
+    <message>
+        <source>It can show offending or sexual explicit photos</source>
+        <translation>Cela peut afficher des photos chocantes ou sexuellement explicites</translation>
+    </message>
 </context>
 <context>
     <name>Ipernity::Item</name>
@@ -789,14 +805,22 @@
         <source>Error</source>
         <translation>Erreur</translation>
     </message>
-    <message>
-        <source>Another istance of</source>
-        <translation>Une autre instance de</translation>
-    </message>
     <message>
         <source>is already running</source>
         <translation>est déjà en cours d&apos;exécution</translation>
     </message>
+    <message>
+        <source>Disclaimer</source>
+        <translation>Avertissement</translation>
+    </message>
+    <message>
+        <source>&lt;b&gt;The Author takes no responsibility over the content that Wally downloads from photo sharing web sites.&lt;br&gt;The Author is in no way responsible for any such content.&lt;/b&gt;&lt;br&gt;&lt;br&gt;If this is a problem for you, please use only local engines like &quot;Files&quot; or local &quot;Folders&quot;.&lt;br&gt;Otherwise, please select &lt;b&gt;&quot;No&quot;&lt;/b&gt; to exit Wally, or use it &lt;b&gt;at your own risk.&lt;/b&gt;&lt;br&gt;&lt;br&gt;(If you proceed, this message will appear only once)&lt;br&gt;&lt;br&gt;Do you accept the above condition?</source>
+        <translation>&lt;b&gt;L&apos;Auteur n&apos;a aucune responsabilité sur le contenu que Wally télécharge depuis les sites de partage de photos.&lt;br&gt;L&apos;Auteur n&apos;est en rien responsable d&apos;un tel contenu.&lt;/b&gt;&lt;br&gt;&lt;br&gt;Si cela vous pose problème, s&apos;il vous plait n&apos;utilisez que les moteurs de recherche locaux tels que &quot;Fichiers&quot; ou &quot;Dossiers&quot;.&lt;br&gt;Sinon, sélectionnez &lt;b&gt;Non&lt;/b&gt; pour quitter Wally, ou utilisez-le &lt;b&gt;à vos risques et périls.&lt;/b&gt;&lt;br&gt;&lt;br&gt;(Si vous continuez ce message n&apos;apparaitra qu&apos;une seule fois)&lt;br&gt;&lt;br&gt;Acceptez-vous les conditions ci-dessus ?</translation>
+    </message>
+    <message>
+        <source>Another instance of</source>
+        <translation>Une autre instance de</translation>
+    </message>
 </context>
 <context>
     <name>Map::View</name>
@@ -976,6 +1000,14 @@
         <source>Any of these words</source>
         <translation>N&apos;importe lequel de ces mots</translation>
     </message>
+    <message>
+        <source>Photobucket item</source>
+        <translation>Recherche Photobucket</translation>
+    </message>
+    <message>
+        <source>It can show offending or sexual explicit photos</source>
+        <translation>Cela peut afficher des photos chocantes ou sexuellement explicites</translation>
+    </message>
 </context>
 <context>
     <name>Photobucket::Item</name>
@@ -1839,6 +1871,14 @@ Voulez le supprimer quand même ?</translation>
         <source>Active Desktop must be disabled</source>
         <translation>Active Desktop doit être désactivé</translation>
     </message>
+    <message>
+        <source>Catalan</source>
+        <translation>Catalan</translation>
+    </message>
+    <message>
+        <source>Greek</source>
+        <translation>Grec</translation>
+    </message>
 </context>
 <context>
     <name>Yahoo::DialogWidget</name>
