@@ -110,7 +110,7 @@ QUrl Item::doPrepareInit(QHttpRequestHeader & /* header */)
   return QUrl();
 }
 
-QUrl Item::doPrepareSearch(QHttpRequestHeader & /* header */)
+QUrl Item::doPrepareSearch(QHttpRequestHeader & /* header */, bool & /* shouldEncode */)
 {
   QUrl url("http://api.flickr.com/services/rest");
 
@@ -119,7 +119,7 @@ QUrl Item::doPrepareSearch(QHttpRequestHeader & /* header */)
 
   if (!_tags.isEmpty())
   {
-    url.addEncodedQueryItem("tags",QUrl::toPercentEncoding(_tags.join(",")));
+    url.addQueryItem("tags",_tags.join(","));
     url.addQueryItem("tag_mode",(_tagsCondition == And)? "all" : "any");
   }
   else if (!_text.isEmpty())
@@ -159,7 +159,7 @@ bool Item::doProcessSearchResult(const QByteArray &response, int &newPagesCount)
         _photoId = xmlResp.attributes().value("id").toString();
     }
 
-  return (!respError && !_photoId.isEmpty() && (_lastPhotoId != _photoId));
+  return (!respError && !_photoId.isEmpty() && !_lastPhotoIds.contains(_photoId));
 }
 
 QUrl Item::prepareSizeRequest(QHttpRequestHeader & /* header */)
@@ -271,9 +271,11 @@ QUrl Item::prepareInfoCollect(QHttpRequestHeader & /* header */)
 {
   QUrl url("http://api.flickr.com/services/rest");
 
+  _lastPhotoIds.insert(_photoId);
+
   url.addQueryItem("method","flickr.photos.getInfo");
   url.addQueryItem("api_key",FLICKR_API_KEY);
-  url.addQueryItem("photo_id",_lastPhotoId = _photoId);
+  url.addQueryItem("photo_id",_photoId);
 
   return url;
 }
@@ -325,6 +327,10 @@ PhotoInfo Item::doProcessInfoCollectResult(const QByteArray &response)
 
 void Item::doLoadSettings(QSettings &settings)
 {
+  QByteArray data;
+  QBuffer buf(&data);
+  QDataStream in(&buf);
+
   if (!settings.value(SEARCH_TAGS,QString()).toString().isEmpty())
   {
     _tags = settings.value(SEARCH_TAGS,QString()).toString().split(" ");
@@ -333,7 +339,12 @@ void Item::doLoadSettings(QSettings &settings)
   else if (!settings.value(SEARCH_TEXT,QString()).toString().isEmpty())
     _text = settings.value(SEARCH_TEXT,QString()).toString();
 
-  _lastPhotoId = settings.value(LAST_PHOTO_ID,QString()).toString();
+  data = qUncompress(settings.value(LAST_PHOTO_IDS,QByteArray()).toByteArray());
+
+  buf.open(QIODevice::ReadOnly);
+  in >> _lastPhotoIds;
+  buf.close();
+
   setSearchOrder(static_cast<SearchOrder> (settings.value(SEARCH_ORDER,DatePostedAsc).toInt()));
   setRequestedSize(static_cast<RequestedSize> (settings.value(REQUESTED_SIZE,Largest).toInt()));
 }
@@ -351,7 +362,15 @@ void Item::doSaveSettings(QSettings &settings) const
 
 void Item::doSaveState(QSettings &settings) const
 {
-  settings.setValue(LAST_PHOTO_ID,_lastPhotoId);
+  QByteArray data;
+  QBuffer buf(&data);
+  QDataStream out(&buf);
+
+  buf.open(QIODevice::WriteOnly);
+  out << _lastPhotoIds;
+  buf.close();
+
+  settings.setValue(LAST_PHOTO_IDS,qCompress(data));
 }
 
 bool Item::equalTo(Engine::Item *item) const
