@@ -113,25 +113,15 @@ void Item::fileListAvailable()
 
 LocalItem::LocalItem(const QString &tempStorageDir) : Item(tempStorageDir)
 {
-  watcher = new QFileSystemWatcher(this);
-
-  connect(watcher,SIGNAL(directoryChanged(const QString &)),
-          this,SLOT(directoryHasChanged(const QString &)));
 }
 
 LocalItem::LocalItem(LocalItem *item) : Item(item->tempStorageDir()), QDir(*item)
 {
-  watcher = new QFileSystemWatcher(this);
-
-  connect(watcher,SIGNAL(directoryChanged(const QString &)),
-          this,SLOT(directoryHasChanged(const QString &)));
-
   _recursion = item->isRecursion();
 }
 
 void LocalItem::buildFileList()
 {
-  QStringList paths = watcher->directories();
   QFileInfo fileInfo;
   QDirIterator scan(absolutePath(),
                     (isRecursion())? QDirIterator::Subdirectories : QDirIterator::NoIteratorFlags);
@@ -139,38 +129,17 @@ void LocalItem::buildFileList()
   qDebug() << metaObject()->className() << "::buildFileList()";
 
   fileList.clear();
-  if (paths.size())
-    watcher->removePaths(paths);
 
-  paths.clear();
   while (scan.hasNext())
-    if ((fileInfo = scan.next()).isReadable())
+    if ((fileInfo = scan.next()).isReadable() && fileInfo.isFile())
     {
-      if (fileInfo.isDir() &&
-          (fileInfo.absoluteFilePath().compare(absolutePath(),Qt::CaseInsensitive) >= 0))
-      {
-         if (isRecursion() && !paths.contains(fileInfo.absoluteFilePath(),Qt::CaseInsensitive))
-         {
-           paths << fileInfo.absoluteFilePath();
+      fileList << fileInfo.absoluteFilePath();
 
-           qDebug() << "\tfound (dir):" << fileInfo.absoluteFilePath().toAscii().constData();
-         }
-      }
-      else if (fileInfo.isFile())
-      {
-        fileList << fileInfo.absoluteFilePath();
-
-        qDebug() << "\tfound (file):" << fileInfo.absoluteFilePath().toAscii().constData();
-      }
+      qDebug() << "\tfound (file):" << fileInfo.absoluteFilePath().toAscii().constData();
     }
 
   qSort(fileList.begin(),fileList.end(),fileNameLessThan);
 
-#ifndef Q_WS_MAC
-  if (paths.size())
-    watcher->addPaths(paths);
-#endif
-
   emit fileListBuilt();
 }
 
@@ -184,14 +153,6 @@ QVariant LocalItem::data() const
   return str;
 }
 
-void LocalItem::directoryHasChanged(const QString &path)
-{
-  qDebug() << metaObject()->className() << "::directoryHasChanged(" << path.toAscii().constData() << ")";
-
-  fileList.clear();
-  clearRandomIndexesList();
-}
-
 void LocalItem::doExtractFileName()
 {
   emit searchCompleted(fileList.at(selectedIndex));
