@@ -515,10 +515,17 @@ void Dialog::execSetAsBackground()
 
 void Dialog::execGetExifInfo()
 {
+  QByteArray tagsData;
   int row = photosSelectionModel->currentIndex().row();
 
-  Exif::InfoDialog((!photosQueryModel->record(row).isNull("exif"))? photosQueryModel->record(row).value("exif").toByteArray() :
-                                                                    QByteArray()).exec();
+  if (!photosQueryModel->record(row).isNull("exif"))
+  {
+    tagsData = qUncompress(photosQueryModel->record(row).value("exif").toByteArray());
+    if (tagsData.isEmpty())
+      tagsData = photosQueryModel->record(row).value("exif").toByteArray();
+  }
+
+  Exif::InfoDialog(tagsData).exec();
 }
 
 void Dialog::execViewPhoto()
