@@ -122,7 +122,7 @@ void Item::processInitResult(const QByteArray &response)
   doProcessInitResult(response);
 }
 
-QUrl Item::prepareSearch(bool randomMode, QHttpRequestHeader &header)
+QUrl Item::prepareSearch(bool randomMode, QHttpRequestHeader &header, bool &shouldEncode)
 {
   QString debugMsg = QString(metaObject()->className()) + "::doCalculateNextIndex(" + ((randomMode)? "true" : "false") +
                      "," + QString::number(_pageIndex) + "," + QString::number(_pages) + ") ->";
@@ -136,7 +136,7 @@ QUrl Item::prepareSearch(bool randomMode, QHttpRequestHeader &header)
 
   qDebug() << debugMsg << _pageIndex;
 
-  return doPrepareSearch(header);
+  return doPrepareSearch(header,shouldEncode);
 }
 
 bool Item::processSearchResult(const QByteArray &response)
@@ -282,7 +282,7 @@ void Core::init()
 
       initHttp->setHost(url.host());
 
-      urlStr = url.toString();
+      urlStr = url.toEncoded();
 
       if (header.keys().size())
         initHttp->request(header,urlStr.remove(0,url.toString(QUrl::RemoveQuery).size()+1).toAscii());
@@ -299,12 +299,13 @@ void Core::search(bool randomMode)
   QUrl url;
   QString urlStr;
   QHttpRequestHeader header;
+  bool shouldEncode = true;
 
   qDebug() << name().toAscii().constData() << "::Core::search(" << randomMode << ")";
 
   if (list.size())
   {
-    url = qobject_cast<Item *> (list.at(currentItemIndex))->prepareSearch(randomMode,header);
+    url = qobject_cast<Item *> (list.at(currentItemIndex))->prepareSearch(randomMode,header,shouldEncode);
 
     qDebug() << "\tURL:" << (!(url.isEmpty())? url.toEncoded().constData() : "empty");
 
@@ -321,13 +322,18 @@ void Core::search(bool randomMode)
 
       searchHttp->setHost(url.host());
 
-      urlStr = url.toString();
+      urlStr = (shouldEncode)? url.toEncoded() : url.toString();
 
       if (header.keys().size())
         searchHttp->request(header,urlStr.remove(0,url.toString(QUrl::RemoveQuery).size()+1).toAscii());
       else
-        searchHttp->get(url.encodedPath() + urlStr.remove(0,urlStr.indexOf(url.path()) +
-                                                          url.path().size()));
+      {
+        if (shouldEncode)
+          searchHttp->get(urlStr.remove(0,urlStr.indexOf(url.path())));
+        else
+          searchHttp->get(url.encodedPath() + urlStr.remove(0,urlStr.indexOf(url.path()) +
+                                                            url.path().size()));
+      }
     }
   }
   else
@@ -355,7 +361,7 @@ void Core::sizeLookup()
 
     sizeRequestHttp->setHost(url.host());
 
-    urlStr = url.toString();
+    urlStr = url.toEncoded();
 
     if (header.keys().size())
       sizeRequestHttp->request(header,urlStr.remove(0,url.toString(QUrl::RemoveQuery).size()+1).toAscii());
@@ -418,7 +424,7 @@ void Core::infoCollect()
 
     infoCollectHttp->setHost(url.host());
 
-    urlStr = url.toString();
+    urlStr = url.toEncoded();
 
     if (header.keys().size())
       infoCollectHttp->request(header,urlStr.remove(0,url.toString(QUrl::RemoveQuery).size()+1).toAscii());
