@@ -327,6 +327,8 @@ void Timeout::processTimeout()
 
 Retry::Retry(Interface *interface) : Base(interface)
 {
+  dumpState(_state);
+
   _state = Idle;
   _tries = DEFAULT_TRIES;
   _aborted = false;
@@ -341,6 +343,8 @@ Retry::Retry(Interface *interface) : Base(interface)
 
 int Retry::get(const QString &path, QIODevice *to)
 {
+  dumpState(_state);
+
   QHttpRequestHeader req("GET",path);
 
   req.addValue("Host",lastHostName);
@@ -378,6 +382,8 @@ int Retry::post(const QString & /* path */, const QByteArray & /* data */, QIODe
 
 int Retry::request(const QHttpRequestHeader &header, QIODevice *data, QIODevice *to)
 {
+  dumpState(_state);
+
   QHttpRequestHeader req = header;
 
   req.addValue("Accept-Ranges","bytes");
@@ -404,6 +410,8 @@ int Retry::request(const QHttpRequestHeader &header, QIODevice *data, QIODevice
 
 int Retry::request(const QHttpRequestHeader &header, const QByteArray &data, QIODevice *to)
 {
+  dumpState(_state);
+
   QHttpRequestHeader req = header;
 
   req.addValue("Accept-Ranges","bytes");
@@ -428,6 +436,8 @@ int Retry::request(const QHttpRequestHeader &header, const QByteArray &data, QIO
 
 int Retry::setHost(const QString &hostName, quint16 port)
 {
+  dumpState(_state);
+
   lastHostName = hostName;
   lastPort = port;
   lastConnectionMode = QHttp::ConnectionModeHttp;
@@ -437,6 +447,8 @@ int Retry::setHost(const QString &hostName, quint16 port)
 
 int Retry::setHost(const QString &hostName, QHttp::ConnectionMode mode, quint16 port)
 {
+  dumpState(_state);
+
   lastHostName = hostName;
   lastPort = port;
   lastConnectionMode = mode;
@@ -446,6 +458,8 @@ int Retry::setHost(const QString &hostName, QHttp::ConnectionMode mode, quint16
 
 void Retry::initPointers()
 {
+  dumpState(_state);
+
   switch (_state)
   {
     case Init:
@@ -469,6 +483,8 @@ void Retry::initPointers()
 
 void Retry::tryAgain()
 {
+  dumpState(_state);
+
   QHttpRequestHeader req = lastRequest;
 
   Base::setHost(lastHostName,lastConnectionMode,lastPort);
@@ -489,6 +505,8 @@ void Retry::tryAgain()
 
 void Retry::saveCurrentRequest(const QHttpResponseHeader &resp)
 {
+  dumpState(_state);
+
   switch (_state)
   {
     case StoreRequest:
@@ -509,6 +527,8 @@ void Retry::saveCurrentRequest(const QHttpResponseHeader &resp)
 
 void Retry::updatePointers(int done, int total)
 {
+  dumpState(_state);
+
   switch (_state)
   {
     case Downloading:
@@ -536,6 +556,8 @@ void Retry::updatePointers(int done, int total)
 
 void Retry::processResult(bool error)
 {
+  dumpState(_state);
+
   switch (_state)
   {
     case Downloading:
@@ -604,8 +626,35 @@ void Retry::processResult(bool error)
   }
 }
 
+void Retry::dumpState(States state)
+{
+  switch (state)
+  {
+    case Idle:
+      qWarning() << "Retry: state = Idle";
+      break;
+
+    case Init:
+      qWarning() << "Retry: state = Init";
+      break;
+
+    case StoreRequest:
+      qWarning() << "Retry: state = StoreRequest";
+      break;
+
+    case Downloading:
+      qWarning() << "Retry: state = Downloading";
+      break;
+
+    case Closed:
+      qWarning() << "Retry: state = Closed";
+  }
+}
+
 void Retry::evaluateNewState(int state)
 {
+  dumpState(_state);
+
   switch (state)
   {
     case QHttp::Unconnected:
@@ -613,10 +662,13 @@ void Retry::evaluateNewState(int state)
       {
         case Idle:
         case Init:
-        case StoreRequest:
         case Downloading:
           break;
 
+        case StoreRequest:
+          _state = Idle;
+          break;
+
         case Closed:
           if (!_aborted)
           {
@@ -639,6 +691,8 @@ void Retry::evaluateNewState(int state)
 
 void Retry::abort()
 {
+  dumpState(_state);
+
   _aborted = true;
   Base::abort();
 }
