@@ -72,8 +72,8 @@ Application::Application(int &argc, char **argv) : QApplication(argc,argv)
   QStringList args = arguments();
   debugMode = args.contains("-debug",Qt::CaseInsensitive);
   httpDebugMode = args.contains("-debughttp",Qt::CaseInsensitive);
-  contextMenu = cancelContextMenu = 0;
-  dontSwitchState = singleInstance = commandLineHelp = false;
+  languagesMenu = contextMenu = cancelContextMenu = 0;
+  dontSwitchState = singleInstance = commandLineHelp = playWasActive = playTimerWasActive = false;
   hiddenWidgetForLanguagesActions = 0;
 
   qInstallMsgHandler(printDebugMsg);
@@ -139,87 +139,6 @@ Application::Application(int &argc, char **argv) : QApplication(argc,argv)
       setApplicationName(APPLICATION_NAME);
       setApplicationVersion(APPLICATION_VERSION);
       setOrganizationName("BeCrux");
-
-      setupTrayIcon();
-      setupActions();
-      setupMenu();
-      setQuitOnLastWindowClosed(false);
-      qsrand(QDateTime::currentDateTime().toTime_t());
-
-    #ifdef Q_WS_X11
-      QDir(QDir::homePath()).mkdir(TEMP_PATH);
-      _tempStorageDir = QDir::homePath() + "/" + TEMP_PATH;
-    #else
-      QDir::home().root().mkpath(QDesktopServices::storageLocation(QDesktopServices::DataLocation));
-      _tempStorageDir = QDesktopServices::storageLocation(QDesktopServices::DataLocation);
-    #endif
-
-      QSettings settings;
-      QTranslator *translator;
-
-      translator = new QTranslator(this);
-      translator->load(":/languages/italian");
-      translators[QLocale(QLocale::Italian).name()] = translator;
-
-      translator = new QTranslator(this);
-      translator->load(":/languages/spanish");
-      translators[QLocale(QLocale::Spanish).name()] = translator;
-
-      translator = new QTranslator(this);
-      translator->load(":/languages/german");
-      translators[QLocale(QLocale::German).name()] = translator;
-
-      translator = new QTranslator(this);
-      translator->load(":/languages/french");
-      translators[QLocale(QLocale::French).name()] = translator;
-
-      translator = new QTranslator(this);
-      translator->load(":/languages/russian");
-      translators[QLocale(QLocale::Russian).name()] = translator;
-
-      translator = new QTranslator(this);
-      translator->load(":/languages/brazilian_portuguese");
-      translators[QLocale(QLocale::Portuguese,QLocale::Brazil).name()] = translator;
-
-      translator = new QTranslator(this);
-      translator->load(":/languages/czech");
-      translators[QLocale(QLocale::Czech,QLocale::CzechRepublic).name()] = translator;
-
-      translator = new QTranslator(this);
-      translator->load(":/languages/polish");
-      translators[QLocale(QLocale::Polish,QLocale::Poland).name()] = translator;
-
-      translator = new QTranslator(this);
-      translator->load(":/languages/chinese");
-      translators[QLocale(QLocale::Chinese,QLocale::China).name()] = translator;
-
-      currentLocale = QLocale::English;
-      settings.beginGroup(MAIN_SECTION);
-      changeLanguage(settings.value(LOCALE,QLocale::system().name()).toString());
-      settings.endGroup();
-
-      currentState = sIdle;
-
-      currentEngineIndex = -1;
-
-      timer = new QTimer(this);
-      timer->setSingleShot(true);
-      timer->setInterval(DEFAULT_INTERVAL * 60000);
-      connect(timer,SIGNAL(timeout()),this,SLOT(start()));
-
-      if ((captureKeymaps = !trayIcon->isSystemTrayAvailable()))
-      {
-        #ifdef Q_WS_X11
-          XGrabKey(QX11Info::display(),AnyKey,AnyModifier,QX11Info::appRootWindow(),
-                  true,GrabModeSync,GrabModeSync);
-        #endif
-      }
-
-      #ifdef Q_WS_X11
-        autoDetectWM();
-      #endif
-
-      initializeDB();
     }
   }
 }
@@ -236,7 +155,8 @@ Application::~Application()
 
   delete hiddenWidgetForLanguagesActions;
 
-  qDeleteAll(engines);
+  if (engines.size())
+    qDeleteAll(engines);
 
 #ifndef Q_WS_WIN
   QFile::remove(_tempStorageDir + "/" + RUN_PATH + "/" + PID_FILENAME);
@@ -248,6 +168,98 @@ Application::~Application()
 #endif
 }
 
+void Application::initialize()
+{
+  setupTrayIcon();
+  setupActions();
+  setupMenu();
+  setQuitOnLastWindowClosed(false);
+  qsrand(QDateTime::currentDateTime().toTime_t());
+
+#ifdef Q_WS_X11
+  QDir(QDir::homePath()).mkdir(TEMP_PATH);
+  _tempStorageDir = QDir::homePath() + "/" + TEMP_PATH;
+#else
+  QDir::home().root().mkpath(QDesktopServices::storageLocation(QDesktopServices::DataLocation));
+  _tempStorageDir = QDesktopServices::storageLocation(QDesktopServices::DataLocation);
+#endif
+
+  QSettings settings;
+  QTranslator *translator;
+
+  translator = new QTranslator(this);
+  translator->load(":/languages/italian");
+  translators[QLocale(QLocale::Italian).name()] = translator;
+
+  translator = new QTranslator(this);
+  translator->load(":/languages/spanish");
+  translators[QLocale(QLocale::Spanish).name()] = translator;
+
+  translator = new QTranslator(this);
+  translator->load(":/languages/german");
+  translators[QLocale(QLocale::German).name()] = translator;
+
+  translator = new QTranslator(this);
+  translator->load(":/languages/french");
+  translators[QLocale(QLocale::French).name()] = translator;
+
+  translator = new QTranslator(this);
+  translator->load(":/languages/russian");
+  translators[QLocale(QLocale::Russian).name()] = translator;
+
+  translator = new QTranslator(this);
+  translator->load(":/languages/brazilian_portuguese");
+  translators[QLocale(QLocale::Portuguese,QLocale::Brazil).name()] = translator;
+
+  translator = new QTranslator(this);
+  translator->load(":/languages/czech");
+  translators[QLocale(QLocale::Czech,QLocale::CzechRepublic).name()] = translator;
+
+  translator = new QTranslator(this);
+  translator->load(":/languages/polish");
+  translators[QLocale(QLocale::Polish,QLocale::Poland).name()] = translator;
+
+  translator = new QTranslator(this);
+  translator->load(":/languages/chinese");
+  translators[QLocale(QLocale::Chinese,QLocale::China).name()] = translator;
+
+  translator = new QTranslator(this);
+  translator->load(":/languages/catalan");
+  translators[QLocale(QLocale::Catalan,QLocale::Andorra).name()] = translator;
+
+  translator = new QTranslator(this);
+  translator->load(":/languages/greek");
+  translators[QLocale(QLocale::Greek,QLocale::Greece).name()] = translator;
+
+  currentLocale = QLocale::English;
+  settings.beginGroup(MAIN_SECTION);
+  changeLanguage(settings.value(LOCALE,QLocale::system().name()).toString());
+  settings.endGroup();
+
+  currentState = sIdle;
+
+  currentEngineIndex = -1;
+
+  timer = new QTimer(this);
+  timer->setSingleShot(true);
+  timer->setInterval(DEFAULT_INTERVAL * 60000);
+  connect(timer,SIGNAL(timeout()),this,SLOT(start()));
+
+  if ((captureKeymaps = !trayIcon->isSystemTrayAvailable()))
+  {
+    #ifdef Q_WS_X11
+      XGrabKey(QX11Info::display(),AnyKey,AnyModifier,QX11Info::appRootWindow(),
+              true,GrabModeSync,GrabModeSync);
+    #endif
+  }
+
+  #ifdef Q_WS_X11
+    autoDetectWM();
+  #endif
+
+  initializeDB();
+}
+
 void Application::printDebugMsg(QtMsgType type, const char *msg)
 {
   switch (type)
@@ -501,6 +513,18 @@ void Application::setupActions()
                                     QLocale(QLocale::Chinese,QLocale::China).name());
   connect(chineseLanguageAction,SIGNAL(triggered()),languagesSignalMapper,SLOT(map()));
 
+  catalanLanguageAction = new QAction(QIcon(":/images/catalonia"),QString(),this);
+  languagesActions << catalanLanguageAction;
+  languagesSignalMapper->setMapping(catalanLanguageAction,
+                                    QLocale(QLocale::Catalan,QLocale::Andorra).name());
+  connect(catalanLanguageAction,SIGNAL(triggered()),languagesSignalMapper,SLOT(map()));
+
+  greekLanguageAction = new QAction(QIcon(":/images/greece"),QString(),this);
+  languagesActions << greekLanguageAction;
+  languagesSignalMapper->setMapping(greekLanguageAction,
+                                    QLocale(QLocale::Greek,QLocale::Greece).name());
+  connect(greekLanguageAction,SIGNAL(triggered()),languagesSignalMapper,SLOT(map()));
+
   hiddenWidgetForLanguagesActions->addActions(languagesActions);
 }
 
@@ -534,6 +558,8 @@ void Application::retranslateMenu()
   czechLanguageAction->setText(tr("Czech"));
   polishLanguageAction->setText(tr("Polish"));
   chineseLanguageAction->setText(tr("Chinese"));
+  catalanLanguageAction->setText(tr("Catalan"));
+  greekLanguageAction->setText(tr("Greek"));
 
   languagesMenu->clear();
   qSort(languagesActions.begin(),languagesActions.end(),actionCaseSensitiveLessThan);
@@ -585,6 +611,8 @@ void Application::setupMenu()
   languagesMenu->addAction(czechLanguageAction);
   languagesMenu->addAction(polishLanguageAction);
   languagesMenu->addAction(chineseLanguageAction);
+  languagesMenu->addAction(catalanLanguageAction);
+  languagesMenu->addAction(greekLanguageAction);
 
   contextMenu = new QMenu;
   contextMenu->addAction(playAction);
@@ -614,6 +642,8 @@ void Application::setupTrayIcon()
 
   trayIcon->setToolTip(QString(APPLICATION_NAME) + " " + QString(APPLICATION_VERSION));
   connect(this,SIGNAL(aboutToQuit()),trayIcon,SLOT(hide()));
+  connect(trayIcon,SIGNAL(activated(QSystemTrayIcon::ActivationReason)),
+          this,SLOT(execTrayAction(QSystemTrayIcon::ActivationReason)));
 
   trayIcon->show();
 }
@@ -646,43 +676,44 @@ void Application::autoDetectWM()
 
     if (ok)
     {
-      if (QFileInfo(file.peekNext().absoluteFilePath() + "/exe").symLinkTarget().contains("kdeinit") &&
-          !QFileInfo(file.peekNext().absoluteFilePath() + "/exe").symLinkTarget().contains("kdeinit4"))
+      QString fName = QFileInfo(QFileInfo(file.peekNext().absoluteFilePath() + "/exe").symLinkTarget()).fileName();
+
+      if (fName.startsWith("kdeinit") && !fName.startsWith("kdeinit4"))
       {
         windowManager = wmKDE3;
         debugMsg += "detected KDE3";
       }
-      else if (QFileInfo(file.peekNext().absoluteFilePath() + "/exe").symLinkTarget().contains("kdeinit4"))
+      else if (fName.startsWith("kdeinit4"))
       {
         windowManager = wmKDE4;
         debugMsg += "detected KDE4";
       }
-      else if (QFileInfo(file.peekNext().absoluteFilePath() + "/exe").symLinkTarget().contains("gconfd-2"))
+      else if (fName.contains("gconfd-2"))
       {
         windowManager = wmGnome;
         debugMsg += "detected Gnome";
       }
-      else if (QFileInfo(file.peekNext().absoluteFilePath() + "/exe").symLinkTarget().contains("xfdesktop"))
+      else if (fName.contains("xfdesktop"))
       {
         windowManager = wmXfce;
         debugMsg += "detected XFCE";
       }
-      else if (QFileInfo(file.peekNext().absoluteFilePath() + "/exe").symLinkTarget().contains("fluxbox"))
+      else if (fName.contains("fluxbox"))
       {
         windowManager = wmFluxbox;
         debugMsg += "detected FluxBox";
       }
-      else if (QFileInfo(file.peekNext().absoluteFilePath() + "/exe").symLinkTarget().contains("fvwm"))
+      else if (fName.contains("fvwm"))
       {
         windowManager = wmFVWM;
         debugMsg += "detected FVWM";
       }
-      else if (QFileInfo(file.peekNext().absoluteFilePath() + "/exe").symLinkTarget().contains("blackbox"))
+      else if (fName.contains("blackbox"))
       {
         windowManager = wmBlackbox;
         debugMsg += "detected BlackBox";
       }
-      else if (QFileInfo(file.peekNext().absoluteFilePath() + "/exe").symLinkTarget().contains("wmaker"))
+      else if (fName.contains("wmaker"))
       {
         windowManager = wmWindowMaker;
         debugMsg += "detected WindowMaker";
@@ -747,7 +778,7 @@ void Application::switchToNextState(Events event)
 
               if (currentEngineIndex == markEngineIndex)
               {
-                trayIcon->setIcon(QIcon(":/images/idle"));
+                trayIcon->setIcon(QIcon((playWasActive)? ":/images/idle" : ":/images/off"));
                 trayIcon->setContextMenu(contextMenu);
                 currentState = sIdle;
                 timer->start();
@@ -823,7 +854,7 @@ void Application::switchToNextState(Events event)
             currentEngineIndex = (currentEngineIndex + 1) % engines.size();
           if (currentEngineIndex == markEngineIndex)
           {
-            trayIcon->setIcon(QIcon(":/images/idle"));
+            trayIcon->setIcon(QIcon((playWasActive)? ":/images/idle" : ":/images/off"));
             trayIcon->setContextMenu(contextMenu);
             currentState = sIdle;
             timer->start();
@@ -888,7 +919,7 @@ void Application::switchToNextState(Events event)
 
         case eDownloadFailed:
           saveEnginesState();
-          trayIcon->setIcon(QIcon(":/images/idle"));
+          trayIcon->setIcon(QIcon((playWasActive)? ":/images/idle" : ":/images/off"));
           trayIcon->setContextMenu(contextMenu);
           currentState = sIdle;
           timer->start();
@@ -925,7 +956,7 @@ void Application::switchToNextState(Events event)
           #ifdef EXIF
             getExifInfoAction->setEnabled(true);
           #endif
-          trayIcon->setIcon(QIcon(":/images/idle"));
+          trayIcon->setIcon(QIcon((playWasActive)? ":/images/idle" : ":/images/off"));
           trayIcon->setContextMenu(contextMenu);
           currentState = sIdle;
           timer->start();
@@ -953,7 +984,7 @@ void Application::switchToNextState(Events event)
       switch (event)
       {
         case eOk:
-          trayIcon->setIcon(QIcon(":/images/idle"));
+          trayIcon->setIcon(QIcon((playWasActive)? ":/images/idle" : ":/images/off"));
           trayIcon->setContextMenu(contextMenu);
           currentState = sIdle;
           timer->start();
@@ -966,6 +997,19 @@ void Application::switchToNextState(Events event)
   }
 }
 
+void Application::execTrayAction(QSystemTrayIcon::ActivationReason reason)
+{
+  switch (reason)
+  {
+    case QSystemTrayIcon::DoubleClick:
+      if ((currentState == sIdle) && playAction->isEnabled())
+        nextPhotoAction->trigger();
+
+    default:
+      break;
+  }
+}
+
 void Application::start()
 {
   switchToNextState(ePlayTimeout);
@@ -1083,10 +1127,6 @@ void Application::processCollectedInfo(const PhotoInfo &info)
            << info.title.toAscii().constData() << ")";
 
   currentPhotoInfo = info;
-  currentPhotoInfo.title = currentPhotoInfo.title;
-  currentPhotoInfo.description = currentPhotoInfo.description;
-  currentPhotoInfo.owner = currentPhotoInfo.owner;
-  currentPhotoInfo.location = currentPhotoInfo.location;
   viewSourceAction->setEnabled(!currentPhotoInfo.sourceUrl.isEmpty() &&
                                currentPhotoInfo.sourceUrl.isValid());
   switchToNextState(eOk);
@@ -1095,7 +1135,7 @@ void Application::processCollectedInfo(const PhotoInfo &info)
 void Application::tryCompletePhotoInfo()
 {
 #ifdef EXIF
-  Exif::Tags tags(currentFile.absoluteFilePath());
+  Exif::Tags tags(currentFile);
 
   if (currentPhotoInfo.owner.isEmpty())
     currentPhotoInfo.owner = tags.owner();
@@ -1106,6 +1146,9 @@ void Application::tryCompletePhotoInfo()
   if (currentPhotoInfo.description.isEmpty())
     currentPhotoInfo.description = tags.description();
 #endif
+
+  if (currentPhotoInfo.title.isEmpty())
+    currentPhotoInfo.title = currentFile.baseName();
 }
 
 void Application::switchToIdle()
@@ -1197,6 +1240,8 @@ void Application::initializeDB()
   {
     QSqlQuery query(db);
 
+    query.exec("PRAGMA journal_mode = OFF");
+
     if (query.exec("select * from sqlite_master where name = 'photoHistory'"))
     {
       if (!query.next() &&
@@ -1230,7 +1275,8 @@ void Application::initializeDB()
 
 void Application::updateDB()
 {
-  Exif::Tags tags(currentFile.absoluteFilePath());
+  Exif::Tags tags(currentFile);
+  QByteArray cTags;
   int now = QDateTime::currentDateTime().toTime_t();
 
   qDebug() << "Application::updateDB()";
@@ -1270,7 +1316,10 @@ void Application::updateDB()
     query.bindValue(":width",currentPhotoSize.width());
     query.bindValue(":height",currentPhotoSize.height());
     if (tags.size())
-      query.bindValue(":exif",tags.data(),QSql::Binary | QSql::In);
+    {
+      cTags = qCompress(tags.data());
+      query.bindValue(":exif",cTags,QSql::Binary | QSql::In);
+    }
 
     if (query.exec())
     {
@@ -1282,7 +1331,7 @@ void Application::updateDB()
         thumb = thumb.scaledToHeight(100,Qt::SmoothTransformation);
 
       if (settings.value(MAIN_SECTION).value(EXIF_ROTATE_IMAGES).toBool())
-        thumb = Exif::Tags(currentFile.absoluteFilePath()).normalize(thumb);
+        thumb = Exif::Tags(currentFile).normalize(thumb);
 
       thumb.save(_tempStorageDir + "/thumbs/" + QString::number(now) + ".png","png");
     }
@@ -1466,8 +1515,6 @@ void Application::showPhotoOnScreen()
       {
         if (!currentPhotoInfo.title.isEmpty())
           toolTip += QString("<b>\"") + currentPhotoInfo.title + "\"</b>";
-        else
-          toolTip += QString("<b>\"") + currentFile.baseName() + "\"</b>";
         lastWasTitle = true;
         if (!currentPhotoInfo.description.isEmpty())
         {
@@ -1702,7 +1749,7 @@ QFileInfo Application::adaptPhoto(const QFileInfo &file, const QString &format,
     throw;
 
   if (settings.value(MAIN_SECTION).value(EXIF_ROTATE_IMAGES).toBool())
-    image = Exif::Tags(file.absoluteFilePath()).normalize(image);
+    image = Exif::Tags(file).normalize(image);
 
   QImage newImage(QApplication::desktop()->screenGeometry().width(),
                   QApplication::desktop()->screenGeometry().height(),QImage::Format_ARGB32);
@@ -1804,6 +1851,8 @@ void Application::execPlay()
 {
   qDebug() << "Application::execPlay()";
 
+  playWasActive = true;
+
   trayIcon->setIcon(QIcon(":/images/idle"));
 
   playAction->setText(tr("Pause"));
@@ -1823,6 +1872,7 @@ void Application::execPause()
 {
   qDebug() << "Application::execPause()";
 
+  playWasActive = false;
   trayIcon->setIcon(QIcon(":/images/off"));
 
   playAction->setText(tr("Play"));
@@ -1979,7 +2029,7 @@ void Application::execGetExifInfo()
 {
   qDebug() << "Application::execGetExifInfo()";
 
-  Exif::InfoDialog dialog(currentFile.absoluteFilePath());
+  Exif::InfoDialog dialog(currentFile);
 
   connect(&dialog,SIGNAL(executed()),this,SLOT(deActivate()));
   connect(&dialog,SIGNAL(closed()),this,SLOT(reActivate()));
@@ -2000,6 +2050,17 @@ void Application::execExploreImageSource()
   QDesktopServices::openUrl(currentPhotoInfo.sourceUrl);
 }
 
+Version Application::currentVersion() const
+{
+  QSettings settings;
+
+  settings.beginGroup(MAIN_SECTION);
+  Version v(settings.value(VERSION,"0.0.0").toString());
+  settings.endGroup();
+
+  return v;
+}
+
 void Application::loadSettings()
 {
   QListIterator<Engine::Core *> engine(engines);
@@ -2028,7 +2089,6 @@ void Application::loadSettings()
   settings[MAIN_SECTION][MIN_FREE_DISK_SPACE_FACTOR] = sourceSettings.value(MIN_FREE_DISK_SPACE_FACTOR,1024);
   settings[MAIN_SECTION][HISTORY_TIME_LIMIT] = sourceSettings.value(HISTORY_TIME_LIMIT,20);
   settings[MAIN_SECTION][HISTORY_TIME_LIMIT_FACTOR] = sourceSettings.value(HISTORY_TIME_LIMIT_FACTOR,0);
-  settings[MAIN_SECTION][MAIN_FIRST_HINT] = sourceSettings.value(MAIN_FIRST_HINT,false);
 
   currentEngineIndex = sourceSettings.value(LAST_USED_ENGINE,-1).toInt();
   sourceSettings.endGroup();
@@ -2089,7 +2149,6 @@ void Application::saveSettings()
   destSettings.setValue(MIN_FREE_DISK_SPACE_FACTOR,settings.value(MAIN_SECTION).value(MIN_FREE_DISK_SPACE_FACTOR));
   destSettings.setValue(HISTORY_TIME_LIMIT,settings.value(MAIN_SECTION).value(HISTORY_TIME_LIMIT));
   destSettings.setValue(HISTORY_TIME_LIMIT_FACTOR,settings.value(MAIN_SECTION).value(HISTORY_TIME_LIMIT_FACTOR));
-  destSettings.setValue(MAIN_FIRST_HINT,settings.value(MAIN_SECTION).value(MAIN_FIRST_HINT));
   destSettings.endGroup();
 
   destSettings.beginGroup(NETWORK_SECTION);
@@ -2232,6 +2291,12 @@ void Application::setupBeforeLaunch()
 {
   qDebug() << "Application::setupBeforeLaunch()";
 
+  QSettings versionSettings;
+
+  versionSettings.beginGroup(MAIN_SECTION);
+  versionSettings.setValue(VERSION,Version(QString(APPLICATION_VERSION)).toString());
+  versionSettings.endGroup();
+
   checkPlayEnableable();
 
   if (playAction->isEnabled() && settings.value(MAIN_SECTION).value(PLAY_ON_START).toBool())
@@ -2345,15 +2410,6 @@ void Application::reActivate()
 
 void Application::showTrayMessage()
 {
-  if (!settings.value(MAIN_SECTION).value(MAIN_FIRST_HINT).toBool())
-  {
-    QSettings destSettings;
-
-    settings[MAIN_SECTION][MAIN_FIRST_HINT] = true;
-    destSettings.beginGroup(MAIN_SECTION);
-    destSettings.setValue(MAIN_FIRST_HINT,settings.value(MAIN_SECTION).value(MAIN_FIRST_HINT));
-    destSettings.endGroup();
-    trayIcon->showMessage(QString("%1 %2").arg(APPLICATION_NAME).arg(APPLICATION_VERSION),
-                          tr("Right-click to show main menu"));
-  }
+  trayIcon->showMessage(QString("%1 %2").arg(APPLICATION_NAME).arg(APPLICATION_VERSION),
+                        tr("Right-click to show main menu"));
 }
